@@ -890,18 +890,68 @@ geom_hockey <- function(league,
       "neutral zone" = c(-half_nzone_length, half_nzone_length),
 
       # Offensive zone
-      "ozone" = c(half_nzone_length, half_rink_length),
-      "offensive_zone" = c(half_nzone_length, half_rink_length),
-      "offensive zone" = c(half_nzone_length, half_rink_length),
-      "attacking_zone" = c(half_nzone_length, half_rink_length),
-      "attacking zone" = c(half_nzone_length, half_rink_length),
+      "ozone" = c(
+        half_nzone_length -
+          (rink_params$major_line_thickness %or% 0) -
+          10,
+        half_rink_length
+      ),
+      "offensive_zone" = c(
+        half_nzone_length -
+          (rink_params$major_line_thickness %or% 0) -
+          10,
+        half_rink_length
+      ),
+      "offensive zone" = c(
+        half_nzone_length -
+          (rink_params$major_line_thickness %or% 0) -
+          10,
+        half_rink_length
+      ),
+      "attacking_zone" = c(
+        half_nzone_length -
+          (rink_params$major_line_thickness %or% 0) -
+          10,
+        half_rink_length
+      ),
+      "attacking zone" = c(
+        half_nzone_length -
+          (rink_params$major_line_thickness %or% 0) -
+          10,
+        half_rink_length
+      ),
 
       # Defensive zone
-      "dzone" = c(-half_rink_length, -half_nzone_length),
-      "defensive_zone" = c(-half_rink_length, -half_nzone_length),
-      "defensive zone" = c(-half_rink_length, -half_nzone_length),
-      "defending_zone" = c(-half_rink_length, -half_nzone_length),
-      "defending zone" = c(-half_rink_length, -half_nzone_length),
+      "dzone" = c(
+        -half_rink_length,
+        -half_nzone_length +
+          (rink_params$major_line_thickness %or% 0) +
+          10
+      ),
+      "defensive_zone" = c(
+        -half_rink_length,
+        -half_nzone_length +
+          (rink_params$major_line_thickness %or% 0) +
+          10
+      ),
+      "defensive zone" = c(
+        -half_rink_length,
+        -half_nzone_length +
+          (rink_params$major_line_thickness %or% 0) +
+          10
+      ),
+      "defending_zone" = c(
+        -half_rink_length,
+        -half_nzone_length +
+          (rink_params$major_line_thickness %or% 0) +
+          10
+      ),
+      "defending zone" = c(
+        -half_rink_length,
+        -half_nzone_length +
+          (rink_params$major_line_thickness %or% 0) +
+          10
+      ),
 
       # Default case
       c(-half_rink_length, half_rink_length)
