@@ -6,6 +6,9 @@ test_that("Error when league is not supplied", {
   # Basketball
   expect_error(geom_basketball())
 
+  # Curling
+  expect_error(geom_curling())
+
   # Football
   expect_error(geom_football())
 
@@ -14,4 +17,7 @@ test_that("Error when league is not supplied", {
 
   # Soccer
   expect_error(geom_soccer())
+
+  # Tennis
+  expect_error(geom_tennis())
 })
